<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu_bbs.cs" ?>

<?cs include:"zeromin2/thread_right_menu.cs" ?>

<div id="main">

<form id="pooledThreadsContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">インデックス</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">スレッド整理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_pooled_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;sort_by=<?cs var:html_escape(SortBy) ?>&amp;descend=<?cs var:html_escape(Descend) ?>" onclick="Zeromin2.redirect(this);return false">プールスレッド整理</a>
</div>

<h1>プールスレッド整理</h1>

<?cs if:Code0 ?>
<?cs if:Done_bbs_create_archive ?><div class="noticeSuccess" id="notify"><p>プールスレッドを過去ログに変換しました</p></div><?cs /if ?>
<?cs if:Done_bbs_restore_pool ?><div class="noticeSuccess" id="notify"><p>プールスレッドを復帰させました</p></div><?cs /if ?>
<?cs if:Done_bbs_remove_pool ?><div class="noticeSuccess" id="notify"><p>プールスレッドを削除しました</p></div><?cs /if ?>
<?cs if:Done_bbs_load_pooled_threads ?><div class="" id="notify"></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs if:Code2 ?><div class="noticeFailed" id="notify"><p>操作対象のプールスレッドが選択されていません</p></div><?cs /if ?>
<?cs /if ?>

<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/zeromin2/lookup.js" charset="UTF-8"></script>
<script type="text/javascript" charset="UTF-8">
//<![CDATA[
jQuery(function(){
Zeromin2.addStyleSheet("<?cs var:html_escape(StaticURI) ?>/css/domTT.css");
});
function lookup( ip, element, event ) {
    Zeromin2.lookup(
        jQuery("#pooledThreadsContainerForm").get(0), ip, element, event );
}
//]]>
</script>

<p>
現在掲示板に存在するプールスレッドを操作します。
</p>
<p>
<ul>
<li>それぞれの項目をクリックするとその項目にあわせて整列されます。</li>
<li>IPアドレス欄はIPアドレスをクリックし、赤くなったらもう一度クリックすることで詳細が表示されます。</li>
<li><code style="font-weight:bold">[HL]</code>をクリックすることで投稿者の投稿記録が全て表示されます。</li>
</ul>
</p>

<p>
チェックされたプールスレッドを<br />
<select name="method">
  <option value="create_archive">過去ログに変換</option>
  <option value="restore_pool">復帰</option>
  <option value="remove_pool">削除</option>
</select>
<input type="submit" value="実行" />
</p>

<p>
ページ単位：
<input type="text" name="item" size="5" value="<?cs var:html_escape(Item) ?>" /><br />
(&nbsp;<?cs var:html_escape(Total) ?>件&nbsp;-&nbsp;現在<?cs var:html_escape(Current) ?>ページ目&nbsp;)<br />
<span class="page">
<?cs if:Prev ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_pooled_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Prev) ?>&amp;sort_by=<?cs var:html_escape(SortBy) ?>&amp;descend=<?cs var:html_escape(Descend) ?>" onclick="Zeromin2.redirect(this);return false">&lt;&lt;&nbsp;前</a><?cs /if ?>
<?cs each:item = Pages ?>
<a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_pooled_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(item.num) ?>&amp;sort_by=<?cs var:html_escape(SortBy) ?>&amp;descend=<?cs var:html_escape(Descend) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(item.num) ?></a>
<?cs /each ?>
<?cs if:Next ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_pooled_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Next) ?>&amp;sort_by=<?cs var:html_escape(SortBy) ?>&amp;descend=<?cs var:html_escape(Descend) ?>" onclick="Zeromin2.redirect(this);return false">次&nbsp;&gt;&gt;</a><?cs /if ?>
</span>
</p>

<table class="simple">
  <thead>
    <tr>
      <td><input type="checkbox" name="" value="" onclick="Zeromin2.selectAllCheckbox( this, 'thread' )" /></td>
      <td><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_pooled_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;sort_by=subject&amp;descend=<?cs if:Descend ?>0<?cs else ?>1<?cs /if ?>" onclick="Zeromin2.redirect(this);return false">スレッド名</a></td>
      <td><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_pooled_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;sort_by=count&amp;descend=<?cs if:Descend ?>0<?cs else ?>1<?cs /if ?>" onclick="Zeromin2.redirect(this);return false">レス数</a></td>
      <td><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_pooled_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;sort_by=date&amp;descend=<?cs if:Descend ?>0<?cs else ?>1<?cs /if ?>" onclick="Zeromin2.redirect(this);return false">時刻</a></td>
      <td><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_pooled_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;sort_by=ip&amp;descend=<?cs if:Descend ?>0<?cs else ?>1<?cs /if ?>" onclick="Zeromin2.redirect(this);return false">IPアドレス</a></td>
      <td>&nbsp;</td>
    </tr>
  </thead>
  <tbody>
  <?cs each:item = Entries ?>
    <tr><td><input type="checkbox" name="thread" value="<?cs var:html_escape(item.key) ?>" /></td><td><?cs var:item.subject ?></td><td><?cs var:html_escape(item.count) ?></td><td title="<?cs var:html_escape(item.key) ?>"><code><?cs var:html_escape(item.date) ?></code></td><td><a href="javascript:void(0)" onclick="lookup( '<?cs var:html_escape(item.ip) ?>', this, event )"><?cs var:html_escape(item.ip) ?></a></td><td><a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=lookup&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;target=<?cs var:html_escape(item.ip) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">[HL]</a></td></tr>
  <?cs /each ?>
  </tbody>
</table>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="bbs" />
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
<input type="hidden" name="OK" value="load_pooled_threads" />
<input type="hidden" name="NG" value="load_pooled_threads" />
<input type="hidden" name="sort_by" value="<?cs var:html_escape(SortBy) ?>" />
<input type="hidden" name="descend" value="<?cs var:html_escape(Descend) ?>" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>
